GetRuntimeVersionAt

Trait GetRuntimeVersionAt 

pub trait GetRuntimeVersionAt<Block: BlockT> {
    // Required method
    fn runtime_version(
        &self,
        at: <Block as BlockT>::Hash,
        call_context: CallContext,
    ) -> Result<RuntimeVersion, String>;
}
Something that can provide the runtime version at a given block.

Required Methods

fn runtime_version( &self, at: <Block as BlockT>::Hash, call_context: CallContext, ) -> Result<RuntimeVersion, String>

Returns the version of runtime at the given block.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: GetRuntimeVersionAt<Block>, Block: BlockT> GetRuntimeVersionAt<Block> for Arc<T>

Available on crate feature std only.
Source

fn runtime_version( &self, at: <Block as BlockT>::Hash, call_context: CallContext, ) -> Result<RuntimeVersion, String>

Implementors