pub trait GetRuntimeVersionAt<Block: BlockT> {
// Required method
fn runtime_version(
&self,
at: <Block as BlockT>::Hash,
call_context: CallContext,
) -> Result<RuntimeVersion, String>;
}Expand description
Something that can provide the runtime version at a given block.
Required Methods
Sourcefn runtime_version(
&self,
at: <Block as BlockT>::Hash,
call_context: CallContext,
) -> Result<RuntimeVersion, String>
fn runtime_version( &self, at: <Block as BlockT>::Hash, call_context: CallContext, ) -> Result<RuntimeVersion, String>
Returns the version of runtime at the given block.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T: GetRuntimeVersionAt<Block>, Block: BlockT> GetRuntimeVersionAt<Block> for Arc<T>
Available on crate feature std only.
impl<T: GetRuntimeVersionAt<Block>, Block: BlockT> GetRuntimeVersionAt<Block> for Arc<T>
Available on crate feature
std only.